@@ -64,7 +64,11 @@ class ATEPlugin:
         pass
 
     @hookspec
-    def get_tester(tester_name):
+    def get_tester(tester_name, logger: Logger):
+        pass
+
+    @hookspec
+    def get_tester_type(tester_name: str):
         pass
 
     @hookspec
